README - test data for riboplot
===============================
As the test data files are huge, they are not distribued with the program. 

You can download them from 
http://ribogalaxy.ucc.ie/library/browse_libraries?sort=name&f-description=All&f-name=All&operation=browse&id=a799d38679e985db

